@@ -13,7 +13,7 @@ use wry::{
         dpi::LogicalSize,
         event::{Event, WindowEvent},
         event_loop::{ControlFlow, EventLoop, EventLoopWindowTarget},
-        window::{WindowBuilder, WindowId},
+        window::{Theme, WindowBuilder, WindowId},
     },
     http::{header::CONTENT_TYPE, Response},
     webview::{WebView, WebViewBuilder},
@@ -37,7 +37,8 @@ fn create_new_window(
     };
     let mut pre_window = WindowBuilder::new()
         .with_title(to_show.title)
-        .with_window_icon(to_show.icon);
+        .with_window_icon(to_show.icon)
+        .with_theme(Some(Theme::Dark));
 
     if to_show.height.is_some() && to_show.width.is_some() {
         pre_window = pre_window.with_inner_size(LogicalSize::new(
@@ -63,90 +64,106 @@ fn create_new_window(
     let webview = match WebViewBuilder::new(window) {
         Err(error2) => return Err(error2.to_string()),
         Ok(item) => {
-            let protocol = item.with_custom_protocol("wry".into(), move |request| {
-                let path = request.uri().path();
-                let clean_path = &path[1..];
-                let content = content.clone();
-                let mut mime = mime_guess::from_path("index.html");
+            let protocol = item
+                .with_background_color((0, 0, 0, 255))
+                .with_custom_protocol("wry".into(), move |request| {
+                    let path = request.uri().path();
+                    let clean_path = &path[1..];
+                    let content = content.clone();
+                    let mut mime = mime_guess::from_path("index.html");
 
-                let content = if path == "/" {
-                    content.into()
-                } else {
-                    let file_path = if clean_path.starts_with("file://") {
-                        let decoded = decode(&clean_path).expect("UTF-8").to_string();
-                        let path = PathBuf::from(&decoded);
-                        if ":" == &decoded[9..10] {
-                            path.strip_prefix("file://").unwrap().to_path_buf()
-                        } else {
-                            let path = PathBuf::from(&decoded[6..]);
-                            path.to_path_buf()
-                        }
+                    let content = if path == "/" {
+                        content.into()
                     } else {
-                        PathBuf::from(clean_path)
-                    };
-                    let file_path = file_path.to_str().unwrap();
+                        let file_path = if clean_path.starts_with("file://") {
+                            let decoded = decode(&clean_path).expect("UTF-8").to_string();
+                            let path = PathBuf::from(&decoded);
+                            if ":" == &decoded[9..10] {
+                                path.strip_prefix("file://").unwrap().to_path_buf()
+                            } else {
+                                let path = PathBuf::from(&decoded[6..]);
+                                path.to_path_buf()
+                            }
+                        } else {
+                            PathBuf::from(clean_path)
+                        };
+                        let file_path = file_path.to_str().unwrap();
 
-                    mime = mime_guess::from_path(file_path);
-                    match read(canonicalize(file_path).unwrap_or_default()) {
-                        Err(_) => content.into(),
-                        Ok(bytes) => bytes.into(),
-                    }
+                        mime = mime_guess::from_path(file_path);
+                        match read(canonicalize(file_path).unwrap_or_default()) {
+                            Err(_) => content.into(),
+                            Ok(bytes) => bytes.into(),
+                        }
+                    };
+
+                    let mimetype = mime
+                        .first()
+                        .map(|mime| mime.to_string())
+                        .unwrap_or_else(|| "text/plain".to_string());
+
+                    Response::builder()
+                        .header(CONTENT_TYPE, mimetype)
+                        .header("Access-Control-Allow-Origin", "null")
+                        .body(content)
+                        .map_err(Into::into)
+                });
+            let export_image = to_show.export_image.clone();
+            let download_path = to_show.download_path.clone();
+
+            let init_view = if !to_show.data.is_none() || !to_show.figure.is_none() {
+                let variable_name = if !to_show.data.is_none() {
+                    "json_data"
+                } else {
+                    "plotly_figure"
                 };
 
-                let mimetype = mime
-                    .first()
-                    .map(|mime| mime.to_string())
-                    .unwrap_or_else(|| "text/plain".to_string());
+                let variable_value = if !to_show.data.is_none() {
+                    serde_json::to_string(&to_show.data.unwrap()).unwrap_or_default()
+                } else {
+                    serde_json::to_string(&to_show.figure.unwrap()).unwrap_or_default()
+                };
 
-                Response::builder()
-                    .header(CONTENT_TYPE, mimetype)
-                    .header("Access-Control-Allow-Origin", "null")
-                    .body(content)
-                    .map_err(Into::into)
-            });
-            let export_image = to_show.export_image.clone();
-
-            let init_view = if !to_show.figure.is_none() {
-                let plotly_figure = to_show.figure.unwrap();
                 let initialization_script = if !export_image.is_empty() {
                     format!(
-                        "window.plotly_figure = {}; window.save_image = true; window.export_image = '{}';",
-                        serde_json::to_string(&plotly_figure).unwrap_or_default() ,
-                        export_image
+                        "window.{} = {}; window.save_image = true; window.export_image = '{}';",
+                        variable_name, variable_value, export_image
                     )
                 } else {
-                    format!(
-                        "window.plotly_figure = {};",
-                        serde_json::to_string(&plotly_figure).unwrap_or_default()
-                    )
+                    format!("window.{} = {};", variable_name, variable_value)
                 };
-                let protocol = protocol.with_initialization_script(&initialization_script);
-                protocol
+
+                protocol.with_initialization_script(&initialization_script)
             } else {
                 protocol
             };
 
-            // we add a download handler to save the png file
+            // we add a download handler, if export_image is set it takes precedence over download_path
             let init_view = init_view.with_download_started_handler(move |_, suggested_path| {
-                // we change the suggested_path to the export_image
                 if !export_image.is_empty() {
-                    let new_path = PathBuf::from(&export_image).as_path().to_path_buf();
-                    *suggested_path = new_path.clone();
-                    true
-                } else {
-                    true
+                    let mut path = PathBuf::from(&export_image);
+                    if path.is_dir() {
+                        path.push(suggested_path.file_name().unwrap());
+                    }
+                    *suggested_path = path.clone();
+                } else if !download_path.is_empty() {
+                    let mut path = PathBuf::from(&download_path);
+                    if path.is_dir() {
+                        path.push(suggested_path.file_name().unwrap());
+                    }
+                    *suggested_path = path.clone();
                 }
+                true
             });
             let init_view =
                 init_view.with_download_completed_handler(move |_uri, filepath, success| {
                     if !success {
                         println!(
-                            "Failed to download to {}",
+                            "\nFailed to download to {}",
                             filepath.unwrap_or_default().to_str().unwrap_or_default()
                         );
                     } else if !minimized {
                         println!(
-                            "Fished downloading to {}",
+                            "\nFished downloading to {}",
                             filepath.unwrap_or_default().to_str().unwrap_or_default()
                         );
                     }
